{-
Copyright (c) 2017 Ryan Olson

GNU GENERAL PUBLIC LICENSE
    Version 3, 29 June 2007

This file is part of elm-time-range.

elm-time-range is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

elm-time-range is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with elm-time-range.  If not, see <http://www.gnu.org/licenses/>.
-}

module Main exposing (..)

import Html exposing (Html, div, text)
import TimeRange exposing (TimeRange)
import Time exposing (Time)
import Date


main : Html Never
main =
    let
        timeRange =
            TimeRange.fromStartAndEnd
                (toTime
                    "04/17/2017 05:00 PM UTC"
                )
                (toTime
                    "04/17/2017 07:00 PM UTC"
                )
    in
        div []
            [ text (getTimeRangeSummary timeRange)
            ]


getTimeRangeSummary : TimeRange -> String
getTimeRangeSummary timeRange =
    let
        start =
            timeRange
                |> TimeRange.start
                |> Date.fromTime
                |> toString

        end =
            timeRange
                |> TimeRange.end
                |> Date.fromTime
                |> toString

        durationInMinutes =
            timeRange
                |> TimeRange.difference
                |> Time.inMinutes
                |> toString
    in
        "The event starts at "
            ++ start
            ++ " and goes until "
            ++ end
            ++ " and lasts "
            ++ durationInMinutes
            ++ " minutes long"


toTime : String -> Time
toTime dateString =
    dateString
        |> Date.fromString
        |> Result.withDefault (Date.fromTime 0)
        |> Date.toTime
